@@ -1,7 +1,9 @@
+import os.path
 from pathlib import Path
 from typing import Callable, Union
 
 import click
+from cookiecutter.prompt import read_user_choice, read_user_yes_no
 
 from toolkit.scaffold.project.render import generate_rendered_project
 
@@ -43,7 +45,7 @@ def generate_create_project_command(
     )
     @click.option(
         "--project-path",
-        type=click.Path(exists=True, file_okay=False),
+        type=click.Path(file_okay=False),
         default=".",
         help="The path to the final generated project.",
     )
@@ -53,7 +55,13 @@ def generate_create_project_command(
         is_flag=True,
         help="Overwrite existing files.",
     )
-    def create_project(project_path: str, overwrite: bool):
+    @click.option(
+        "--launch-editor",
+        "-e",
+        is_flag=True,
+        help="Launch the editor after generating the project.",
+    )
+    def create_project(project_path: str, overwrite: bool, launch_editor: bool):
         generate_rendered_project(
             template_paths=template_paths,
             project_path=project_path,
@@ -66,4 +74,21 @@ def generate_create_project_command(
             overwrite=overwrite,
         )
 
+        click.echo(f"Project created at:\n{os.path.abspath(project_path)}")
+
+        if launch_editor or read_user_yes_no("Launch editor?", True):
+            click.edit(
+                editor=read_user_choice(
+                    "Which editor to use?",
+                    [
+                        "code",
+                        "clion",
+                        "golang",
+                        "pycharm",
+                    ],
+                ),
+                filename=project_path,
+                require_save=False,
+            )
+
     return create_project
