@@ -3,5 +3,5 @@ from toolkit.scaffold.project.template import TEMPLATE_DOCKER_PATH
 
 create_compose = generate_create_project_command(
     command_help="Create a docker-compose project scaffold.",
-    template_path=TEMPLATE_DOCKER_PATH / "compose",
+    template_paths=TEMPLATE_DOCKER_PATH / "compose",
 )
