@@ -1,6 +1,7 @@
 #include <QGuiApplication>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include <QFont>
 
 #include "core.h"
 
@@ -9,6 +10,8 @@ int main(int argc, char *argv[]) {
 
   QGuiApplication app(argc, argv);
 
+  QGuiApplication::setFont(QFont("Microsoft YaHei", 14));
+
   Core *core = new Core(&app);
 
   QQmlApplicationEngine engine;
